@@ -13,11 +13,11 @@ use crate::ids::{Id, IdOf};
 use crate::lifecycle::Interrupt;
 use crate::lite_runtime::Tag;
 use anyhow::Error;
-use futures::channel::mpsc;
-use futures::{SinkExt, Stream};
+use futures::Stream;
 use std::fmt;
 use std::hash::{Hash, Hasher};
 use std::time::Instant;
+use tokio::sync::mpsc;
 
 /// `Address` to send messages to `Actor`.
 ///
@@ -96,7 +96,24 @@ impl<A: Actor> Address<A> {
         A: ActionHandler<I>,
     {
         let envelope = Envelope::new(input);
-        self.msg_tx.send(envelope).await.map_err(Error::from)
+        self.msg_tx
+            .send(envelope)
+            .await
+            // TODO: Improve that
+            .map_err(|err| Error::msg(err.to_string()))
+    }
+
+    /// Sends an `Action` by blockign the current thread.
+    pub fn blocking_act<I>(&mut self, input: I) -> Result<(), Error>
+    where
+        I: Action,
+        A: ActionHandler<I>,
+    {
+        let envelope = Envelope::new(input);
+        self.msg_tx
+            .blocking_send(envelope)
+            // TODO: Improve that
+            .map_err(|err| Error::msg(err.to_string()))
     }
 
     /// Just sends an `Action` to the `Actor`.
@@ -127,7 +144,7 @@ impl<A: Actor> Address<A> {
     /// Send a `Parcel` to unpacking.
     pub fn unpack_parcel(&self, parcel: Parcel<A>) -> Result<(), Error> {
         self.hp_msg_tx
-            .unbounded_send(parcel)
+            .send(parcel)
             .map_err(|_| Error::msg("can't send a high-priority service message"))
     }
 
